@@ -10,6 +10,7 @@
 #' @param col A vector of colors to color the clusters in
 #'   \code{x}.  Should have same length as the number of
 #'   clusters in \code{x}.
+#' @inheritParams summary.smerc_cluster
 #' @return Returns a vector with colors for each
 #'   region/centroid for the data set used to construct
 #'   \code{x}.
@@ -19,17 +20,27 @@
 #' data(nydf)
 #' coords = with(nydf, cbind(longitude, latitude))
 #' out = scan.test(coords = coords, cases = floor(nydf$cases),
-#'                 pop = nydf$pop, alpha = 0.12, longlat = TRUE,
+#'                 pop = nydf$pop, alpha = 0.2, longlat = TRUE,
 #'                 nsim = 9)
 #' data(nypoly)
 #' library(sp)
-#' plot(nypoly, col = color.clusters(out))
-color.clusters = function(x, col = grDevices::hcl.colors(length(x$clusters))) {
+#' # plot all clusters
+#' plot(nypoly, col = color.clusters(out), axes = TRUE)
+#' # zoom in on small cluster
+#' plot(nypoly, col = color.clusters(out),
+#'      xlim = c(400000, 450000),
+#'      ylim = c(4750000, 4800000))
+#' # plot only clusters 1 and 3
+#' plot(nypoly, col = color.clusters(out, idx = c(1, 3)))
+color.clusters = function(x, idx = seq_along(x$clusters), col = grDevices::hcl.colors(length(idx))) {
   if (class(x) != "scan" & class(x) != "smerc_cluster") {
     stop("x should be an object of class scan or smerc_cluster.")
   }
-  if (length(x$clusters) != length(col)) {
-    stop("The number of colors must match the number of clusters.")
+  if (min(idx) < 1 | max(idx) > length(x$clusters)) {
+    stop("invalid idx values")
+  }
+  if (length(idx) != length(col)) {
+    stop("The number of colors must match the length of idx.")
   }
 
   mycol = numeric(nrow(x$coords))
