@@ -19,25 +19,41 @@
 #'
 #' @inheritParams dmst.test
 #'
-#' @return Returns a list of length two of class scan. The first element (clusters) is a list containing the significant, non-ovlappering clusters, and has the the following components:
-#' \item{locids}{The location ids of regions in a significant cluster.}
-#' \item{pop}{The total population in the cluser window.}
-#' \item{cases}{The observed number of cases in the cluster window.}
-#' \item{expected}{The expected number of cases in the cluster window.}
-#' \item{smr}{Standarized mortaility ratio (observed/expected) in the cluster window.}
-#' \item{rr}{Relative risk in the cluster window.}
-#' \item{loglikrat}{The loglikelihood ratio for the cluster window (i.e., the log of the test statistic).}
-#' \item{pvalue}{The pvalue of the test statistic associated with the cluster window.}
-#' \item{w}{The adjacency matrix of the cluster.}
-#' \item{r}{The maximum radius of the cluster (in terms of intercentroid distance from the starting region).}
-#' The second element of the list is the centroid coordinates.  This is needed for plotting purposes.
+#' @return Returns a list of length two of class scan. The
+#'   first element (clusters) is a list containing the
+#'   significant, non-ovlappering clusters, and has the the
+#'   following components: \item{locids}{The location ids of
+#'   regions in a significant cluster.} \item{pop}{The total
+#'   population in the cluser window.} \item{cases}{The
+#'   observed number of cases in the cluster window.}
+#'   \item{expected}{The expected number of cases in the
+#'   cluster window.} \item{smr}{Standarized mortaility
+#'   ratio (observed/expected) in the cluster window.}
+#'   \item{rr}{Relative risk in the cluster window.}
+#'   \item{loglikrat}{The loglikelihood ratio for the
+#'   cluster window (i.e., the log of the test statistic).}
+#'   \item{pvalue}{The pvalue of the test statistic
+#'   associated with the cluster window.} \item{w}{The
+#'   adjacency matrix of the cluster.} \item{r}{The maximum
+#'   radius of the cluster (in terms of intercentroid
+#'   distance from the starting region).} The second element
+#'   of the list is the centroid coordinates.  This is
+#'   needed for plotting purposes.
 #' @author Joshua French
-#' @importFrom parallel mclapply
-#' @importFrom stats rmultinom
+#' @seealso \code{\link{print.smerc_cluster}},
+#' \code{\link{summary.smerc_cluster}},
+#' \code{\link{plot.smerc_cluster}},
+#' \code{\link{scan.stat}}, \code{\link{scan.test}}
 #' @export
-#' @references Yao, Z., Tang, J., & Zhan, F. B. (2011). Detection of arbitrarily-shaped clusters using a neighbor-expanding approach: A case study on murine typhus in South Texas. International journal of health geographics, 10(1), 1.
+#' @references Yao, Z., Tang, J., & Zhan, F. B. (2011).
+#'   Detection of arbitrarily-shaped clusters using a
+#'   neighbor-expanding approach: A case study on murine
+#'   typhus in South Texas. International journal of health
+#'   geographics, 10(1), 1.
 #'
-#' Assuncao, R.M., Costa, M.A., Tavares, A. and Neto, S.J.F. (2006). Fast detection of arbitrarily shaped disease clusters, Statistics in Medicine, 25, 723-742.
+#'   Assuncao, R.M., Costa, M.A., Tavares, A. and Neto,
+#'   S.J.F. (2006). Fast detection of arbitrarily shaped
+#'   disease clusters, Statistics in Medicine, 25, 723-742.
 #' @examples
 #' data(nydf)
 #' data(nyw)
@@ -90,7 +106,7 @@ mlf.test = function(coords, cases, pop, w,
   # determine which call for simulations
   fcall = pbapply::pblapply
   # setup list for call
-  fcall_list = list(X = as.list(seq_len(nsim)), FUN = function(i){
+  fcall_list = list(X = as.list(seq_len(nsim)), FUN = function(i) {
     # simulate new data set
     ysim = stats::rmultinom(1, size = ty, prob = ex)
 
@@ -109,26 +125,22 @@ mlf.test = function(coords, cases, pop, w,
   # p-values associated with these max statistics for each centroid
   pvalue = (sum(tsim >= max_zone$loglikrat) + 1) / (nsim + 1)
 
-   # if there are no significant clusters, return most likely cluster
-  if (pvalue >= alpha | nsim == 0) {
-    warning("No significant clusters.  Returning most likely cluster.")
-  }
+  # significant, ordered, non-overlapping clusters and
+  # information
+  pruned = sig_noc(tobs = max_zone$loglikrat,
+                   zones = list(max_zone$locids),
+                   pvalue = pvalue, alpha = alpha,
+                   order_by = "tobs")
 
-  # for the most likely cluster:
-  # find the zone radius, p-value, standarized mortality ratio,
-  # relative risk, adjacency matrix and max radius
-  startpt = coords[start, ] # starting region
-  max_zone$r = max(sp::spDistsN1(coords[max_zone$locids, ],
-                                 startpt, longlat = longlat))
-  max_zone$pvalue = pvalue
-  max_zone$smr = max_zone$cases / max_zone$expected
-  rr_num = (max_zone$cases / max_zone$pop)
-  rr_den = (ty - max_zone$cases) / (sum(pop) - max_zone$pop)
-  max_zone$rr = rr_num / rr_den
-  max_zone$w = w[max_zone$locids, max_zone$locids]
-
-  # reformat output for return
-  outlist = list(clusters = list(max_zone), coords = coords)
-  class(outlist) = "scan"
-  return(outlist)
+  smerc_cluster(tobs = pruned$tobs, zones = pruned$zones,
+                pvalue = pruned$pvalue, coords = coords,
+                cases = cases, pop = pop, ex = ex,
+                longlat = longlat, method = "maxima likelihood first",
+                rel_param = list(type = "poisson",
+                                 simdist = "multinomial",
+                                 nsim = nsim,
+                                 ubpop = ubpop,
+                                 ubd = ubd),
+                alpha = alpha,
+                w = w, d = NULL)
 }
